==> angular-permission-3.2.1.jar: META-INF/resources/webjars/angular-permission/3.2.1/README.md <==
![angular-permission-banner](https://i.imgsafe.org/d6c48d4.png)

Permission
============================

*Fully featured role and permission based access control for your angular applications*

![Bower](https://img.shields.io/bower/v/angular-permission.svg?style=flat-square)
![npm](https://img.shields.io/npm/v/angular-permission.svg?style=flat-square)
![Travis](https://img.shields.io/travis/Narzerus/angular-permission.svg?style=flat-square)
![Coveralls](https://img.shields.io/coveralls/Narzerus/angular-permission.svg?style=flat-square)

Permission helps you gain control of your routes, by using simple concepts for you to decide who can access them.
We've seen plenty of big fat tutorials on access control implementation, and they can be quite overwhelming or inconsistent. 
So we bring you a elastic, powerful and yet straightforward solution, that allow you provide fine-grained 
role and permission based access control for your application users.

<img src="https://res.cloudinary.com/hashnode/image/upload/v1451902371/static_imgs/story-stats-icon.png" width="48" height="48">&nbsp;Documentation and examples
----------------------------

Want to know more? See [the wiki](https://github.com/Narzerus/angular-permission/wiki).

<img src="https://s-media-cache-ak0.pinimg.com/236x/57/43/47/574347ddf6be999e0027de121104f2ff.jpg" width="48" height="48">&nbsp;Authors
----------------------------

- [Rafael Vidaurre](https://twitter.com/narzerus) - I'm a full-stack developer and musician who loves creating things of value
- [Blazej Krysiak](https://twitter.com/masterspambot) - I am a fast-minded, creative web developer seeking knowledge in innovative web technologies and cloud-based solutions.

==> angular-permission-5.2.1.jar: META-INF/resources/webjars/angular-permission/5.2.1/README.md <==
![angular-permission-banner](https://i.imgsafe.org/b839736863.jpg)

Permission
============================

*Fully featured role and permission based access control for your angular applications*

![Bower](https://img.shields.io/bower/v/angular-permission.svg?style=flat-square)
![npm](https://img.shields.io/npm/v/angular-permission.svg?style=flat-square)
![jspm](https://img.shields.io/github/release/Narzerus/angular-permission.svg?label=jspm&style=flat-square)
![Travis](https://img.shields.io/travis/Narzerus/angular-permission.svg?style=flat-square)
![Coveralls](https://img.shields.io/coveralls/Narzerus/angular-permission.svg?style=flat-square)


Permission helps you gain control of your routes, by using simple concepts for you to decide who can access them.
We've seen plenty of big fat tutorials on access control implementation, and they can be quite overwhelming or inconsistent. 
So we bring you a elastic, powerful and yet straightforward solution, that allow you provide fine-grained 
role and permission based access control for your application users.

<img src="https://res.cloudinary.com/hashnode/image/upload/v1451902371/static_imgs/story-stats-icon.png" width="48" height="48">&nbsp;Documentation and examples
----------------------------

Want to know more? See [the wiki](https://github.com/Narzerus/angular-permission/wiki).

<img src="https://s-media-cache-ak0.pinimg.com/236x/57/43/47/574347ddf6be999e0027de121104f2ff.jpg" width="48" height="48">&nbsp;Authors
----------------------------

- [Rafael Vidaurre](https://twitter.com/narzerus) - full-stack developer and musician who loves creating things of value
- [Blazej Krysiak](https://twitter.com/masterspambot) - fast-minded, creative web developer seeking knowledge in innovative web technologies and cloud-based solutions
